@@ -3,6 +3,7 @@ import sys
 import json
 import base64
 import requests
+import hashlib
 
 from .domain import FlowName, JobBuildNumber, AgentToken, Job, ServerUrl, AgentJobDir
 
@@ -15,6 +16,7 @@ HttpHeaders = {
     "AGENT-TOKEN": AgentToken
 }
 
+
 def GetVar(name, required=True):
     val = os.environ.get(name)
     if required and val is None:
@@ -31,7 +33,7 @@ def ToBase64String(strVal):
     return str(b64bytes, 'utf-8')
 
 
-def FindFiles(file, path = AgentJobDir):
+def FindFiles(file, path=AgentJobDir):
     files = []
 
     for i in os.listdir(path):
@@ -46,13 +48,21 @@ def FindFiles(file, path = AgentJobDir):
     return files
 
 
+def MD5(path):
+    md5Hash = hashlib.md5()
+    with open(path, "rb") as f:
+        for byte_block in iter(lambda: f.read(4096), b""):
+            md5Hash.update(byte_block)
+        return md5Hash.hexdigest()
+
+
 class Client:
     def __init__(self):
         pass
 
     def getCredential(self, name):
         try:
-            url = "{}/api/credential/{}".format(ServerUrl, name)
+            url = "{}/api/secret/{}".format(ServerUrl, name)
             r = requests.get(url=url, headers=HttpHeaderWithJson)
             if r.status_code is 200:
                 body = r.text
@@ -63,6 +73,20 @@ class Client:
             print(e)
             return None
 
+    def getConfig(self, name):
+        try:
+            url = "{}/api/config/{}".format(ServerUrl, name)
+            r = requests.get(url=url, headers=HttpHeaderWithJson)
+            if r.status_code is 200:
+                body = r.text
+                return json.loads(body)
+
+            return None
+        except Exception as e:
+            print(e)
+            return None
+
+
     def listFlowUsers(self):
         try:
             url = "{}/api/flow/{}/users".format(ServerUrl, FlowName)
@@ -98,13 +122,21 @@ class Client:
             print(e)
             return -1
 
-    def uploadJobArtifact(self, path):
+    def uploadJobArtifact(self, path, srcDir=None):
         try:
             url = "{}/api/flow/{}/job/{}/artifact".format(
                 ServerUrl, FlowName, JobBuildNumber)
 
+            body = {
+                "md5": MD5(path)
+            }
+
+            if srcDir != None:
+                body["srcDir"] = srcDir
+
             r = requests.post(url=url, headers=HttpHeaders, files={
-                'file': open(path, 'rb')
+                'file': open(path, 'rb'),
+                "body": ('', json.dumps(body), 'application/json')
             })
 
             return r.status_code
@@ -115,7 +147,8 @@ class Client:
     def sendStatistic(self, body):
         try:
             url = "{}/api/flow/{}/stats".format(ServerUrl, FlowName)
-            r = requests.post(url=url, headers=HttpHeaderWithJson, data=json.dumps(body))
+            r = requests.post(
+                url=url, headers=HttpHeaderWithJson, data=json.dumps(body))
             return r.status_code
         except Exception as e:
             print(e)
@@ -123,10 +156,11 @@ class Client:
 
     def addJobContext(self, var):
         try:
-            url = "{}/api/flow/{}/job/{}/context".format(ServerUrl, FlowName, JobBuildNumber)
+            url = "{}/api/flow/{}/job/{}/context".format(
+                ServerUrl, FlowName, JobBuildNumber)
             r = requests.post(url=url, headers=HttpHeaderWithJson,
                               data=json.dumps(var))
             return r.status_code
         except Exception as e:
             print(e)
-            return -1
\ No newline at end of file
+            return -1
